# PROCESS ARCENE DATA - STAGE 2.

source("../../select.r")
source("../../pca.r")
source("../../plot.r")

# Find pvalues for tests of association of features with class. 

pval.perm.trim <- perm.pval(train.trim,ranks=TRUE)

pval.hyper.trim <- hyper.pval(train.n0[ix.trim],train.n1[ix.trim])

pval.runs.trim <- runs.pval(train.trim)  # TAKES ABOUT HALF AN HOUR

# Produce various plots of p-values.

postscript("dexter2a.ps",horizontal=TRUE)

par(mfrow=c(2,3))

minp <- 0.5/length(ix.trim)

plot (pmax(minp,sort(pval.perm.trim)), pch=20, log="y", ylab="",
      xlab="Permutation test p-values", ylim=c(minp,1))
lines(1:length(ix.trim),((1:length(ix.trim))-0.5)/length(ix.trim))
abline(v=c(0,500,1000),lty=3)

plot (pmax(minp,sort(pval.hyper.trim)), pch=20, log="y", ylab="",
      xlab="Binary hypergeometric p-values", ylim=c(minp,1))
lines(1:length(ix.trim),((1:length(ix.trim))-0.5)/length(ix.trim))
abline(v=c(0,500,1000),lty=3)

plot (pmax(minp,sort(pval.runs.trim)), pch=20, log="y", ylab="", 
      xlab="Runs test p-values", ylim=c(minp,1))
lines(1:length(ix.trim),((1:length(ix.trim))-0.5)/length(ix.trim))
abline(v=c(0,500,1000),lty=3)

jitter <- exp(rnorm(length(ix.trim),0,0.05))

plot (pval.perm.trim*jitter, pval.hyper.trim*jitter, log="xy", pch=20,
      xlab="Permutation test p-values", ylab="Binary hypergeometric p-values")
abline(h=quantile(pval.hyper.trim,c(0.001,0.01,0.1)))
abline(v=quantile(pval.perm.trim,c(0.001,0.01,0.1)))

plot (pval.hyper.trim*jitter, pval.runs.trim*jitter, log="xy", pch=20,
      xlab="Binary hypergeometric p-values", ylab="Runs test p-values")
abline(h=quantile(pval.runs.trim,c(0.001,0.01,0.1)))
abline(v=quantile(pval.hyper.trim,c(0.001,0.01,0.1)))

plot (pval.runs.trim*jitter, pval.perm.trim*jitter, log="xy", pch=20,
      xlab="Runs test p-values", ylab="Permutation test p-values")
abline(h=quantile(pval.perm.trim,c(0.001,0.01,0.1)))
abline(v=quantile(pval.runs.trim,c(0.001,0.01,0.1)))

dev.off()

# Select a set of features using these pvalues.

sel.perm <- order(pval.perm.trim)[1:234]   # p-value <= 0.05
sel.hyper <- order(pval.hyper.trim)[1:199] # p-value <= 0.05
sel.runs <- order(pval.runs.trim)[1:147]   # p-value <= 0.05
sel <- union(sel.perm,union(sel.hyper,sel.runs))
ix.sel <- ix.trim[sel]

write.ix(ix.sel,"sel")
write.data(ix.sel,"sel")

# Find the first 40 principle components from the trimmed set of features,
# with no centering or scaling.

pca.trim <- 
  pca.vectors (all.trim, 40, center=FALSE, scale=FALSE) # TAKES ABOUT A MINUTE
                                                        # REQUIRES ABOUT 1 GBYTE

write.pca (pca.trim, "pc", train.trim, valid.trim, test.trim)
