# PROCESS GISETTE DATA - STAGE 3.

# Get ARD hyperparameters from MCMC runs for neural net models, as well
# as magnitudes of coefficients for logistic regression models.

read.dense()  # Read train.x, valid.x, and test.x again

wmags.lr.sel <- 
  read.matrix(pipe("net-tbl W1@ lr-sel.log 41:"),ncol=length(ix.sel))
hypers.nn.sel <- 
  read.matrix(pipe("net-tbl h1@ nn-sel.log 41:"),ncol=length(ix.sel))

# Compute overall relevance of variables from ARD hyperparameters or 
# logistic regression coefficients and standard deviations of variables.

qnt <- function (x) quantile(x,0.75)

rel.lr.sel <- apply(wmags.lr.sel,2,qnt) * 
              apply(train.x[,ix.sel],2,sd)
rel.nn.sel <- apply(hypers.nn.sel,2,qnt) * 
              apply(train.x[,ix.sel],2,sd)

# Plot these relevances.

postscript("gisette3a.ps",horizontal=TRUE)

plot(rel.lr.sel,rel.nn.sel,pch=20,log="xy")
abline (v=-sort(-rel.lr.sel)[c(50,100,200)], 
        h=-sort(-rel.nn.sel)[c(50,100,200)])

dev.off()

# Find a reduced set of features based on these relevances.

ix.red <- union (ix.sel[order(-rel.nn.sel)[1:200]], 
                 ix.sel[order(-rel.lr.sel)[1:200]])
write.ix(ix.red,"red")
write.data(ix.red,"red")

rm(train.x,valid.x,test.x)
